@@ -1,14 +1,17 @@
 r"""
+Geometry
+--------
+
 This submodule contains pore-scale models that calculate geometrical
 properties. These models are to be added to a Geometry object.
-"""
 
+"""
+from ._geodocs import *
 from . import pore_size
 from . import pore_seed
 from . import pore_volume
 from . import pore_surface_area
 from . import pore_cross_sectional_area
-from . import throat_endpoints
 from . import throat_cross_sectional_area
 from . import throat_seed
 from . import throat_size
@@ -18,11 +21,8 @@ from . import throat_surface_area
 from . import throat_volume
 from . import throat_capillary_shape_factor
 from . import throat_centroid
+from . import throat_endpoints
 from . import throat_vector
 from . import hydraulic_size_factors
 from . import diffusive_size_factors
 from . import conduit_lengths
-
-# Up for deprecation
-pore_area = pore_cross_sectional_area
-throat_area = throat_cross_sectional_area
